==> azureml_telemetry-1.0rc83-py3-none-any.whl: azureml/telemetry/logger/_abstract_event_logger.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""Base class for all loggers."""
from abc import ABC, abstractmethod
from os import getenv
import uuid

from azureml.telemetry.log_scope import LogScope as _LogScope
from azureml.telemetry.contracts import StandardFieldKeys

HBI_WORKSPACE_JOB_KEY = 'HBI_WORKSPACE_JOB'
HBI_MODE = getenv(HBI_WORKSPACE_JOB_KEY, 'false').lower() != 'false'

try:
    from azureml._base_sdk_common import _ClientSessionId
    _telemetry_session_id = _ClientSessionId
except ImportError:
    _telemetry_session_id = str(uuid.uuid4())


class AbstractEventLogger(ABC):
    """Abstract event logger class."""

    @abstractmethod
    def log_event(self, telemetry_event, white_listed_properties=None):
        """
        Log event.

        :param telemetry_event: the event to be logged
        :type telemetry_event: TelemetryObjectBase
        :param white_listed_properties: properties that could be logged without redaction
        :return: Event GUID.
        :rtype: str
        """
        raise NotImplementedError()

    @abstractmethod
    def log_metric(self, telemetry_metric, white_listed_properties=None):
        """
        Log metric.

        :param telemetry_metric: the metric to be logged
        :type telemetry_metric: TelemetryObjectBase
        :param white_listed_properties: properties that could be logged without redaction
        :return: Metric GUID.
        :rtype: str
        """
        raise NotImplementedError()

    @abstractmethod
    def flush(self):
        """Flush the telemetry client."""
        raise NotImplementedError()

    SESSION_ID = "SessionId"
    SAMPLE_NOTEBOOK_NAME = "SampleNotebookName"

    @staticmethod
    def _redact_fill_props_with_context(telemetry_entry, white_listed_properties=None):
        """Fill telemetry props with context info.

        :param telemetry_entry: event or metric
        :param white_listed_properties: list of property names from extension properties and context that
            should be skipped during redacting
        :type telemetry_entry: TelemetryObjectBase
        :return properties with context info
        :rtype: dict
        """
        white_listed_properties = white_listed_properties or []
        if HBI_MODE:
            for key in _common_standard_redaction_fields:
                # deal with common fields that need to be redacted
                if key in telemetry_entry.standard_fields and key not in white_listed_properties:
                    telemetry_entry.standard_fields[key] = AbstractEventLogger._redact_string(
                        telemetry_entry.standard_fields[key])
            if telemetry_entry.extension_fields:
                # redact all not white-listed extension fields if needed
                for key in telemetry_entry.extension_fields.keys():
                    if key in white_listed_properties:
                        continue
                    telemetry_entry.extension_fields[key] = AbstractEventLogger._redact_string(
                        telemetry_entry.extension_fields[key])

        props = telemetry_entry.get_all_properties()
        ctx = _LogScope.get_current()
        # merge values from parent scope if any
        props = props if ctx is None else ctx.get_merged_props(props, HBI_MODE, white_listed_properties)
        # set global session id
        props[AbstractEventLogger.SESSION_ID] = _telemetry_session_id
        # set SampleNotebookName if any
        sample_notebook_name = getenv(AbstractEventLogger.SAMPLE_NOTEBOOK_NAME)
        if sample_notebook_name:
            props[AbstractEventLogger.SAMPLE_NOTEBOOK_NAME] = sample_notebook_name

        return props

    @staticmethod
    def _redact_string(value_to_redact):
        return '[REDACTED]'


_common_standard_redaction_fields = [StandardFieldKeys.RUN_ID_KEY, StandardFieldKeys.PARENT_RUN_ID_KEY]

==> azureml_telemetry-1.0.65-py3-none-any.whl: azureml/telemetry/logger/_abstract_event_logger.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""Base class for all loggers."""
from abc import ABC, abstractmethod

from azureml.telemetry.log_scope import LogScope as _LogScope


class AbstractEventLogger(ABC):
    """Abstract event logger class."""

    @abstractmethod
    def log_event(self, telemetry_event):
        """
        Log event.

        :param telemetry_event: the event to be logged
        :type telemetry_event: TelemetryObjectBase
        :return: Event GUID.
        :rtype: str
        """
        raise NotImplementedError()

    @abstractmethod
    def log_metric(self, telemetry_metric):
        """
        Log metric.

        :param telemetry_metric: the metric to be logged
        :type telemetry_metric: TelemetryObjectBase
        :return: Metric GUID.
        :rtype: str
        """
        raise NotImplementedError()

    @abstractmethod
    def flush(self):
        """Flush the telemetry client."""
        raise NotImplementedError()

    def _fill_props_with_context(self, telemetry_entry):
        """Fill telemetry props with context info.

        :param telemetry_entry: event or metric
        :type telemetry_entry: TelemetryObjectBase
        :return properties with context info
        :rtype: dict
        """
        props = telemetry_entry.get_all_properties()
        ctx = _LogScope.get_current()
        return props if ctx is None else ctx.get_merged_props(props)
